cal.Subscription (Subscription) — amici1

# `cal.Subscription` (Subscription)

Subscription(id, user, calendar, is_hidden)

Master tables : cal.Subscriptions (Subscriptions)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Author (user) : The author of this object. A pointer to lino.modlib.users.models.User.

- Calendar (calendar) : The calendar you want to subscribe to.

- hidden (is_hidden)Whether this subscription should “

    “initially be displayed as a hidden calendar.

- Name (name_column) : See `lino_xl.lib.cal.models.Subscription.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.cal.models.Subscription.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.cal.models.Subscription.overview`.

Referenced from

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
user | Author | The author of this object. A pointer to lino.modlib.users.models.User.
calendar | Calendar | The calendar you want to subscribe to.
is_hidden | hidden | Whether this subscription should “ “initially be displayed as a hidden calendar.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |